@@ -1,6 +1,5 @@
 # -*- encoding: utf-8 -*-
 from __future__ import absolute_import, division, print_function, unicode_literals
-
 from .model_base import ModelBase
 
 
@@ -8,11 +7,7 @@ class H2OCoxPHModel(ModelBase):
 
     def formula(self):
         """Survival formula."""
-        return self._model_json["output"]["formula"] 
-        
-    def concordance(self):
-        """Concordance"""
-        return self._model_json["output"]["concordance"]
+        return self._model_json["output"]["formula"]
 
     def coefficients_table(self):
         """Coefficients table."""
@@ -25,6 +20,5 @@ class H2OCoxPHModel(ModelBase):
         print(self.coefficients_table())
         output = self._model_json["output"]
         print("Likelihood ratio test=%f" % (output["loglik_test"]))
-        print("Concordance=%f" % (output["loglik_test"]))
         print("n=%d, number of events=%d" % (output["n"], output["total_event"]))
 
